@@ -1,4 +1,4 @@
-# $Id: MeCab.pm 2 2006-05-02 02:11:10Z daisuke $
+# $Id: MeCab.pm 3 2006-05-02 02:29:14Z daisuke $
 #
 # Copyright (c) 2006 Daisuke Maki <dmaki@cpan.org>
 # All rights reserved.
@@ -8,7 +8,7 @@ use strict;
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT_OK);
 BEGIN
 {
-    $VERSION = '0.01';
+    $VERSION = '0.02';
     if ($] > 5.006) {
         require XSLoader;
         XSLoader::load(__PACKAGE__, $VERSION);
@@ -25,6 +25,12 @@ BEGIN
     @EXPORT_OK = map { @$_ } values %EXPORT_TAGS;
 }
 
+sub new
+{
+    my $class = shift;
+    return (ref($_[0]) eq 'HASH') ? $class->_new(@_) : $class->_new_optarg(\@_);
+}
+
 1;
 
 __END__
@@ -37,11 +43,11 @@ Text::MeCab - Alternate Interface To libmecab
 
   use Text::MeCab;
   my $mecab = Text::MeCab->new({
-    rcfile => $rcfile,
-    dicdir => $dicdir,
-    uuserdic => $userdic,
-    lattice_level => $lattice_level,
-    all_morphs    => $all_morphs,
+    rcfile             => $rcfile,
+    dicdir             => $dicdir,
+    userdic            => $userdic,
+    lattice_level      => $lattice_level,
+    all_morphs         => $all_morphs,
     output_format_type => $output_format_type,
     partial            => $partial,
     node_format        => $node_format,
@@ -63,23 +69,28 @@ Text::MeCab - Alternate Interface To libmecab
   use Text::MeCab qw(:all);
   use Text::MeCab qw(MECAB_NODE_NODE);
 
+  # want to use a command line arguments?
+  my $mecab = Text::MeCab->new("--userdic=/foo/bar/baz", "-P");
+
 =head1 DESCRIPTION
 
 libmecab (http://mecab.sourceforge.ne.jp) already has a perl interface built 
 with it, so why a new module? I just feel that while a subtle difference,
 making the perl interface through a tied hash is just... weird.
 
-So Text::MeCab gives you a more naturally Perl way to access libmecab!
+So Text::MeCab gives you a more natural, Perl-ish way to access libmecab!
 
 =head1 METHODS
 
-=head2 new HASHREF
+=head2 new HASHREF | LIST
 
-Creates a new Text::MeCab instance. You can specify most the options that you
-could normally pass to the command line "mecab" command.
+Creates a new Text::MeCab instance.
 
-Below is the list of accepted options. See the man page for mecab for details 
-about each option.
+You can either specify a hashref and use named parameters, or you can use the
+exact command line arguments that the mecab command accepts.
+
+Below is the list of accepted named options. See the man page for mecab for 
+details about each option.
 
 =over 4
 
